package cn.bunny.controller;


import cn.bunny.common.spzx.model.dto.product.CategoryBrandDto;
import cn.bunny.common.spzx.model.entity.product.Brand;
import cn.bunny.common.spzx.model.entity.product.CategoryBrand;
import cn.bunny.common.spzx.model.vo.common.Result;
import cn.bunny.common.spzx.model.vo.common.ResultCodeEnum;
import cn.bunny.service.CategoryBrandService;
import com.github.pagehelper.PageInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "分类品牌列表接口")
@RestController
@RequestMapping("/admin/product/categoryBrand")
public class CategoryBrandController {
    @Autowired
    private CategoryBrandService categoryBrandService;

    @Operation(summary = "根据id查询对应商品数据",description = "根据id查询对应商品数据")
    @GetMapping("/findBrandByCategoryId/{categoryId}")
    public Result findBrandByCategoryId(@PathVariable Long categoryId) {
       List<Brand> brandList = categoryBrandService.findBrandByCategoryId(categoryId);
        return Result.build(brandList, ResultCodeEnum.SUCCESS);
    }


    @Operation(summary = "删除分类品牌", description = "删除分类品牌")
    @DeleteMapping("/deleteById/{id}")
    private Result deleteById(@PathVariable Long id) {
        categoryBrandService.deleteById(id);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "分类品牌修改功能", description = "分类品牌修改功能")
    @PutMapping("updateById")
    public Result updateById(@RequestBody CategoryBrand categoryBrand) {
        categoryBrandService.updateById(categoryBrand);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "分类品牌添加", description = "分类品牌添加")
    @PostMapping("save")
    public Result save(@RequestBody CategoryBrand categoryBrand) {
        categoryBrandService.save(categoryBrand);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "分类品牌条件分页查询", description = "分类品牌条件分页查询")
    @GetMapping("/{page}/{limit}")
    public Result findByPage(@PathVariable("page") Integer page,
                             @PathVariable("limit") Integer limit,
                             CategoryBrandDto categoryBrandDto) {
        PageInfo<CategoryBrand> categoryBrandPageInfo = categoryBrandService.findByPage(page, limit, categoryBrandDto);
        return Result.build(categoryBrandPageInfo, ResultCodeEnum.SUCCESS);
    }
}
