package cn.bunny.controller;

import cn.bunny.common.AuthContextUtil;
import cn.bunny.common.spzx.model.dto.system.LoginDto;
import cn.bunny.common.spzx.model.entity.system.SysUser;
import cn.bunny.common.spzx.model.entity.user.UserInfo;
import cn.bunny.common.spzx.model.vo.common.Result;
import cn.bunny.common.spzx.model.vo.common.ResultCodeEnum;
import cn.bunny.common.spzx.model.vo.system.LoginVo;
import cn.bunny.common.spzx.model.vo.system.SysMenuVo;
import cn.bunny.common.spzx.model.vo.system.ValidateCodeVo;
import cn.bunny.service.SysMenuService;
import cn.bunny.service.SysUserService;
import cn.bunny.service.ValidateCodeService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "用户接口")
@Log4j2
@RestController
@RequestMapping("/admin/system/index")
public class IndexController {
    @Autowired
    private SysUserService sysUserService;

    @Autowired
    private ValidateCodeService validateCodeService;

    @Autowired
    private SysMenuService sysMenuService;

    @Operation(summary = "查询用户可以操作菜单", description = "菜单查询")
    @GetMapping("/menus")
    public Result menus() {
        List<SysMenuVo> list = sysMenuService.findMenusByUserId();
        return Result.build(list, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "用户登录", description = "用户登录获取token")
    @PostMapping("login")
    public Result login(@RequestBody LoginDto loginDto) {
        log.info("post --- 用户登录");

        LoginVo loginVo = sysUserService.login(loginDto);
        return Result.build(loginVo, ResultCodeEnum.LOGIN_SUCCESS);
    }

    @Operation(summary = "获取验证码", description = "会获得两个值：codeKey + codeValue")
    @GetMapping(value = "/generateValidateCode")
    public Result<ValidateCodeVo> generateValidateCode() {
        log.info("get --- 获取验证码");

        ValidateCodeVo validateCodeVo = validateCodeService.generateValidateCode();
        return Result.build(validateCodeVo, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "获取用户登录信息", description = "获取token")
    @GetMapping(value = "getUserInfo")
    // public Result getUserInfo(HttpServletRequest httpServletRequest) {
    //     String token = httpServletRequest.getHeader("token");
    public Result<UserInfo> getUserInfo() {
        log.info("get --- 获取用户登录信息");

        return Result.build(AuthContextUtil.get(), ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "获取用户登录信息1", description = "获取token")
    @GetMapping(value = "getUserInfo1")
    public Result getUserInfo(@RequestHeader(name = "token") String token) {
        log.info("get --- 获取用户登录信息");

        SysUser sysUser = sysUserService.getUserInfo(token);
        return Result.build(sysUser, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "用户退出", description = "清除Redis中token")
    @GetMapping("logout")
    public Result logout(@RequestHeader(name = "token") String token) {
        log.info("get --- 用户退出");

        sysUserService.logout(token);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }
}
