package cn.bunny.controller;

import cn.bunny.common.spzx.model.dto.product.ProductDto;
import cn.bunny.common.spzx.model.entity.product.Product;
import cn.bunny.common.spzx.model.vo.common.Result;
import cn.bunny.common.spzx.model.vo.common.ResultCodeEnum;
import cn.bunny.service.ProductService;
import com.github.pagehelper.PageInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "商品管理接口")
@RestController
@RequestMapping("/admin/product/product")
public class ProductController {
    @Autowired
    private ProductService productService;

    @Operation(summary = "商品上下架", description = "商品上下架")
    @GetMapping("/updateStatus/{id}/{status}")
    public Result updateStatus(@PathVariable("id") Long id,
                               @PathVariable("status") Integer status) {
        productService.updateStatus(id, status);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "审核商品", description = "审核商品")
    @GetMapping("/updateAuditStatus/{id}/{auditStatus}")
    public Result updateAuditStatus(@PathVariable("id") Long id,
                                    @PathVariable("auditStatus") Integer auditStatus) {
        productService.updateAuditStatus(id, auditStatus);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "删除数据", description = "删除数据")
    @DeleteMapping("deleteById/{id}")
    public Result deleteById(@Parameter(name = "id", description = "商品id", required = true) Long id) {
        productService.deleteById(id);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "保存修改数据", description = "保存修改数据")
    @PutMapping("updateById")
    public Result updateById(@RequestBody Product product) {
        productService.updateById(product);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "根据id查询商品信息", description = "根据id查询商品信息")
    @GetMapping("getById/{id}")
    public Result getById(@PathVariable("id") Long id) {
        Product product = productService.getById(id);
        return Result.build(product , ResultCodeEnum.SUCCESS) ;
    }

    @Operation(summary = "保存商品数据接口", description = "保存商品数据接口")
    @PostMapping("save")
    public Result save(@RequestBody Product product) {
        productService.save(product);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }


    @Operation(summary = "商品管理查询分页", description = "商品管理查询分页")
    @GetMapping("/{page}/{limit}")
    public Result findByPage(@PathVariable("page") Integer page,
                             @PathVariable("limit") Integer limit,
                             ProductDto productDto) {
        PageInfo<Product> productList = productService.findByPage(page, limit, productDto);
        return Result.build(productList, ResultCodeEnum.SUCCESS);
    }
}
