package cn.bunny.controller;

import cn.bunny.common.spzx.model.entity.product.ProductSpec;
import cn.bunny.common.spzx.model.vo.common.Result;
import cn.bunny.common.spzx.model.vo.common.ResultCodeEnum;
import cn.bunny.service.ProductSpecService;
import com.github.pagehelper.PageInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Tag(name = "商品规格列表接口")
@RestController
@RequestMapping("/admin/product/productSpec")
public class ProductSpecController {
    @Autowired
    private ProductSpecService productSpecService;

    @Operation(summary = "加载商品单元数据",description = "加载商品单元数据")
    @GetMapping("findAll")
    public Result findAll() {
        List<ProductSpec> productSpecList= productSpecService.findAll();
        return Result.build(productSpecList, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "分页查询商品规格列表", description = "分页查询商品规格列表")
    @GetMapping("{page}/{limit}")
    public Result lis(@PathVariable("page") Integer page, @PathVariable("limit") Integer limit) {
        PageInfo<ProductSpec> pageInfo = productSpecService.findByPage(page, limit);
        return Result.build(pageInfo, ResultCodeEnum.SUCCESS);
    }

    @Operation(summary = "商品规格添加", description = "商品规格添加")
    @PostMapping("save")
    public Result save(@RequestBody ProductSpec productSpec) {
        productSpecService.save(productSpec);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }

    /**
     * 分页查询商品规格列表
     *
     * @param productSpec 每页数量
     * @return 商品规格列表
     */
    @Operation(summary = "商品规格修改", description = "商品规格修改")
    @PutMapping("updateById")
    public Result updateById(@RequestBody ProductSpec productSpec) {
        productSpecService.updateById(productSpec);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }

    /**
     * 商品规格删除
     *
     * @param id id
     * @return Result
     */
    @Operation(summary = "商品规格删除", description = "商品规格删除")
    @DeleteMapping("deleteById/{id}")
    public Result deleteById(@PathVariable("id") Integer id) {
        productSpecService.deleteById(id);
        return Result.build(null, ResultCodeEnum.SUCCESS);
    }
}
