package cn.bunny.service.impl;

import cn.bunny.common.spzx.model.dto.product.ProductDto;
import cn.bunny.common.spzx.model.entity.product.Product;
import cn.bunny.common.spzx.model.entity.product.ProductDetails;
import cn.bunny.common.spzx.model.entity.product.ProductSku;
import cn.bunny.mapper.ProductDetailMapper;
import cn.bunny.mapper.ProductMapper;
import cn.bunny.mapper.ProductSkuMapper;
import cn.bunny.service.ProductService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class ProductServiceImpl implements ProductService {
    @Autowired
    private ProductMapper productMapper;

    @Autowired
    private ProductSkuMapper productSkuMapper;

    @Autowired
    private ProductDetailMapper productDetailMapper;

    // 查询分页
    @Override
    public PageInfo<Product> findByPage(Integer page, Integer limit, ProductDto productDto) {
        PageHelper.startPage(page, limit);
        List<Product> productList = productMapper.findByPage(productDto);
        return new PageInfo<>(productList);
    }

    // 保存商品数据接口
    @Override
    public void save(Product product) {
        product.setStatus(0);
        product.setAuditStatus(0);
        productMapper.save(product);

        List<ProductSku> productSkuList = product.getProductSkuList();
        for (int i = 0; i < productSkuList.size(); i++) {
            ProductSku productSku = productSkuList.get(i);
            // 商品编号
            productSku.setSkuCode(product.getId() + "_" + i);
            // 商品Id
            productSku.setProductId(product.getId());
            // skuName
            productSku.setSkuName(product.getName() + productSku.getSkuSpec());
            productSkuMapper.save(productSku);
        }

        ProductDetails productDetails = new ProductDetails();
        productDetails.setProductId(product.getId());
        productDetails.setImageUrls(product.getDetailsImageUrls());
        productDetailMapper.save(productDetails);
    }

    // 根据id查询商品信息
    @Override
    public Product getById(Long id) {

        // 根据id查询商品数据
        Product product = productMapper.findProductById(id);

        // 根据商品的id查询sku数据
        List<ProductSku> productSkuList = productSkuMapper.findProductSkuByProductId(id);
        product.setProductSkuList(productSkuList);

        // 根据商品的id查询商品详情数据
        ProductDetails productDetails = productDetailMapper.findProductDetailsById(product.getId());
        if (productDetails != null) product.setDetailsImageUrls(productDetails.getImageUrls());

        // 返回数据
        return product;
    }

    // 保存修改数据
    @Override
    public void updateById(Product product) {
        // 修改product表
        productMapper.updateProduct(product);

        // 修改product_sku表
        List<ProductSku> productSkuList = product.getProductSkuList();
        for (ProductSku productSku : productSkuList) {
            productSkuMapper.updateById(productSku);
        }

        // 修改product_details表
        String detailsImageUrls = product.getDetailsImageUrls();
        ProductDetails productDetails = productDetailMapper.findProductDetailsById(product.getId());
        productDetails.setImageUrls(detailsImageUrls);
        productDetailMapper.updateById(productDetails);
    }

    // 删除数据
    @Override
    public void deleteById(Long id) {
        // 1. 删除product数据
        productMapper.deleteById(id);

        // 2. 删除product_sku数据
        productSkuMapper.deleteByProductId(id);

        // 3. 删除product_details数据
        productDetailMapper.deleteById(id);
    }

    // 审核商品
    @Override
    public void updateAuditStatus(Long id, Integer auditStatus) {
        Product product = new Product();
        product.setId(id);
        if (auditStatus == 1) {
            product.setAuditStatus(1);
            product.setAuditMessage("审核通过");
        } else {
            product.setAuditStatus(-1);
            product.setAuditMessage("审核不通过");
        }

        productMapper.updateById(product);
    }

    // 商品上下架
    @Override
    public void updateStatus(Long id, Integer status) {
        Product product = new Product();
        product.setId(id);
        if (status == 1) {
            product.setStatus(1);
        } else {
            product.setStatus(-1);
        }

        productMapper.updateById(product);
    }
}
