package cn.bunny.web.product.service.imp;

import cn.bunny.common.spzx.model.entity.product.Category;
import cn.bunny.web.product.mapper.CategoryMapper;
import cn.bunny.web.product.service.CategoryService;
import jakarta.annotation.Resource;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

@Service
public class CategoryServiceImpl implements CategoryService {
    @Resource
    private CategoryMapper categoryMapper;

    // 商品一级分类接口
    @Override
    public List<Category> selectOneCategory() {
        return categoryMapper.selectOneCategory();
    }

    // 获取分类树形数据
    @Override
    public List<Category> findCategoryTree() {
        // 1. 查询所有分类，返回list集合
        List<Category> allCategoryList = categoryMapper.findAll();

        // 2. 遍历所有分类list集合，通过parentId=0得到所有一级分类
        List<Category> categoryList = allCategoryList.stream().filter(item -> item.getParentId() == 0)
                .toList();

        // 3. 编辑所有一级分类list几个，条件判断；id=parentId，得到一级下面二级分类
        categoryList.forEach(category -> {
            List<Category> categories = allCategoryList.stream().filter(item -> Objects.equals(item.getParentId(), category.getId())).collect(Collectors.toList());
            category.setChildren(categories);

            categories.forEach(twoCategory -> {
                List<Category> threeCategorieList = allCategoryList.stream().filter(item -> Objects.equals(item.getParentId(), twoCategory.getId())).toList();
                twoCategory.setChildren(threeCategorieList);
            });
        });

        // 4. 遍历所有二级分类，条件判断；id=parentId得到二级下面三级分类
        return categoryList;
    }
}
